package com.acme;

import org.infinispan.Cache;
import org.infinispan.config.Configuration;
import org.infinispan.config.FluentConfiguration;
import org.infinispan.eviction.EvictionStrategy;
import org.infinispan.manager.DefaultCacheManager;
import org.infinispan.transaction.LockingMode;
import org.infinispan.transaction.TransactionMode;
import org.infinispan.transaction.lookup.JBossStandaloneJTAManagerLookup;
import org.infinispan.tree.TreeCache;
import org.infinispan.tree.TreeCacheFactory;


public class TreeCachePerformance {

  public static void main(String[] args) {
    TreeCache<String, String> treeCache = createTreeCache();
    stressCache(treeCache);
  }

  static void stressCache(TreeCache<String, String> treeCache) {
    int itemCount = 100000;

    for (int i = 0; i < itemCount; i++) {
      String s = "key" + i;
      treeCache.put("prefix", s, s);
    }

    for (int i = 0; i < itemCount; i++) {
      String s = "key" + i;
      String v = treeCache.get("prefix", s);
      if (!s.equals(v)) {
        System.err.printf("expected %s but got %s%n", s, v);
      }
    }
  }

  static <K, V> TreeCache<K, V> createTreeCache() {
    Configuration configuration = new Configuration();
    FluentConfiguration fluent = configuration.fluent();
    fluent.invocationBatching();
    fluent.eviction().strategy(EvictionStrategy.NONE).maxEntries(-1);
    fluent.transactionManagerLookupClass(JBossStandaloneJTAManagerLookup.class);
    fluent.transaction().transactionMode(TransactionMode.TRANSACTIONAL).lockingMode(LockingMode.OPTIMISTIC);
    Cache<Object, Object> infinispanCache = new DefaultCacheManager(configuration).getCache();
    TreeCacheFactory factory = new TreeCacheFactory();
    return (TreeCache<K, V>) factory.createTreeCache(infinispanCache);
  }

}
